==> jc-1.4.0.tar.gz: javax/swing/JOptionPane__241.h <==
// final class javax.swing.JOptionPane$1

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 820dc9b5ad6ec0ae javax_swing_JOptionPane__241
// @dep_class d12a2e5148d3df80 javax_swing_event_InternalFrameAdapter

// header file dependencies
// @dep_header javax_swing_event_InternalFrameAdapter

#include "javax/swing/event/InternalFrameAdapter.h"

#ifndef _JC_javax_swing_JOptionPane__241_H_
#define _JC_javax_swing_JOptionPane__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JInternalFrame$object;
struct _jc_javax_swing_event_InternalFrameEvent$object;

// Typedefs
typedef struct _jc_javax_swing_JOptionPane__241$sub_refs	_jc_javax_swing_JOptionPane__241$sub_refs;
typedef struct _jc_javax_swing_JOptionPane__241$sub_nonrefs	_jc_javax_swing_JOptionPane__241$sub_nonrefs;
typedef struct _jc_javax_swing_JOptionPane__241$refs	_jc_javax_swing_JOptionPane__241$refs;
typedef struct _jc_javax_swing_JOptionPane__241$nonrefs	_jc_javax_swing_JOptionPane__241$nonrefs;
typedef struct _jc_javax_swing_JOptionPane__241$object	_jc_javax_swing_JOptionPane__241$object;

typedef const struct _jc_javax_swing_JOptionPane__241$vmethods	_jc_javax_swing_JOptionPane__241$vmethods;
typedef const struct _jc_javax_swing_JOptionPane__241$vtable	_jc_javax_swing_JOptionPane__241$vtable;
typedef const struct _jc_javax_swing_JOptionPane__241$vtype	_jc_javax_swing_JOptionPane__241$vtype;

// Constructors
extern void _jc_javax_swing_JOptionPane__241$method$_init$cd9aac833f4912ad(_jc_env *, struct _jc_javax_swing_JOptionPane__241$object *, struct _jc_javax_swing_JInternalFrame$object *);

// Virtual methods
extern void _jc_javax_swing_JOptionPane__241$method$internalFrameClosed$febd1034ec9a66ec(_jc_env *, struct _jc_javax_swing_JOptionPane__241$object *, struct _jc_javax_swing_event_InternalFrameEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JOptionPane__241$method_info$internalFrameClosed$febd1034ec9a66ec;

// Virtual methods structure
struct _jc_javax_swing_JOptionPane__241$vmethods {
	void	(*internalFrameClosed$febd1034ec9a66ec)(_jc_env *, struct _jc_javax_swing_JOptionPane__241$object *, struct _jc_javax_swing_event_InternalFrameEvent$object *);
};

// Vtable
struct _jc_javax_swing_JOptionPane__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_event_InternalFrameAdapter$vmethods	javax_swing_event_InternalFrameAdapter;
	_jc_javax_swing_JOptionPane__241$vmethods	javax_swing_JOptionPane__241;
};

// Vtype
struct _jc_javax_swing_JOptionPane__241$vtype {
	_jc_type			type;
	_jc_javax_swing_JOptionPane__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JOptionPane__241$sub_refs {
	struct _jc_javax_swing_JInternalFrame$object	*val__24tmp;
};

// Reference instance fields (object)
struct _jc_javax_swing_JOptionPane__241$refs {
    _jc_javax_swing_JOptionPane__241$sub_refs	javax_swing_JOptionPane__241;
    _jc_javax_swing_event_InternalFrameAdapter$sub_refs	javax_swing_event_InternalFrameAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JOptionPane__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JOptionPane__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_event_InternalFrameAdapter$sub_nonrefs	javax_swing_event_InternalFrameAdapter;
    _jc_javax_swing_JOptionPane__241$sub_nonrefs	javax_swing_JOptionPane__241;
};

// Object instance structure
struct _jc_javax_swing_JOptionPane__241$object {
	_jc_javax_swing_JOptionPane__241$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JOptionPane__241$vtype	*vtype;
	_jc_javax_swing_JOptionPane__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JOptionPane__241$vtype _jc_javax_swing_JOptionPane__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JOptionPane__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JOptionPane__241$class_object;

#endif	/* _JC_javax_swing_JOptionPane__241_H_ */

==> jc-1.4.6.tar.gz: javax/swing/JOptionPane__241.h <==
// final class javax.swing.JOptionPane$1

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 820dc9b5ad6ec0ae javax_swing_JOptionPane__241
// @dep_class d12a2e5148d3df80 javax_swing_event_InternalFrameAdapter

// header file dependencies
// @dep_header javax_swing_event_InternalFrameAdapter

#include "javax/swing/event/InternalFrameAdapter.h"

#ifndef _JC_javax_swing_JOptionPane__241_H_
#define _JC_javax_swing_JOptionPane__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JInternalFrame$object;
struct _jc_javax_swing_event_InternalFrameEvent$object;

// Typedefs
typedef struct _jc_javax_swing_JOptionPane__241$sub_refs	_jc_javax_swing_JOptionPane__241$sub_refs;
typedef struct _jc_javax_swing_JOptionPane__241$sub_nonrefs	_jc_javax_swing_JOptionPane__241$sub_nonrefs;
typedef struct _jc_javax_swing_JOptionPane__241$refs	_jc_javax_swing_JOptionPane__241$refs;
typedef struct _jc_javax_swing_JOptionPane__241$nonrefs	_jc_javax_swing_JOptionPane__241$nonrefs;
typedef struct _jc_javax_swing_JOptionPane__241$object	_jc_javax_swing_JOptionPane__241$object;

typedef const struct _jc_javax_swing_JOptionPane__241$vmethods	_jc_javax_swing_JOptionPane__241$vmethods;
typedef const struct _jc_javax_swing_JOptionPane__241$vtable	_jc_javax_swing_JOptionPane__241$vtable;
typedef const struct _jc_javax_swing_JOptionPane__241$vtype	_jc_javax_swing_JOptionPane__241$vtype;

// Constructors
extern void _jc_javax_swing_JOptionPane__241$method$_init$cd9aac833f4912ad(_jc_env *, struct _jc_javax_swing_JOptionPane__241$object *, struct _jc_javax_swing_JInternalFrame$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_JOptionPane__241$method$internalFrameClosed$febd1034ec9a66ec(_jc_env *, struct _jc_javax_swing_JOptionPane__241$object *, struct _jc_javax_swing_event_InternalFrameEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JOptionPane__241$method_info$internalFrameClosed$febd1034ec9a66ec;

// Virtual methods structure
struct _jc_javax_swing_JOptionPane__241$vmethods {
	void	(*internalFrameClosed$febd1034ec9a66ec)(_jc_env *, struct _jc_javax_swing_JOptionPane__241$object *, struct _jc_javax_swing_event_InternalFrameEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JOptionPane__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_event_InternalFrameAdapter$vmethods	javax_swing_event_InternalFrameAdapter;
	_jc_javax_swing_JOptionPane__241$vmethods	javax_swing_JOptionPane__241;
};

// Vtype
struct _jc_javax_swing_JOptionPane__241$vtype {
	_jc_type			type;
	_jc_javax_swing_JOptionPane__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JOptionPane__241$sub_refs {
	struct _jc_javax_swing_JInternalFrame$object	*val__24tmp;
};

// Reference instance fields (object)
struct _jc_javax_swing_JOptionPane__241$refs {
    _jc_javax_swing_JOptionPane__241$sub_refs	javax_swing_JOptionPane__241;
    _jc_javax_swing_event_InternalFrameAdapter$sub_refs	javax_swing_event_InternalFrameAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JOptionPane__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JOptionPane__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_event_InternalFrameAdapter$sub_nonrefs	javax_swing_event_InternalFrameAdapter;
    _jc_javax_swing_JOptionPane__241$sub_nonrefs	javax_swing_JOptionPane__241;
};

// Object instance structure
struct _jc_javax_swing_JOptionPane__241$object {
	_jc_javax_swing_JOptionPane__241$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JOptionPane__241$vtype	*vtype;
	_jc_javax_swing_JOptionPane__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JOptionPane__241$vtype _jc_javax_swing_JOptionPane__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JOptionPane__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JOptionPane__241$class_object;

#endif	/* _JC_javax_swing_JOptionPane__241_H_ */
